@@ -11,8 +11,15 @@
 #define  ABSTRACT_DEFAULT 	NULL
 #define  VOLSET_ID_DEFAULT 	NULL
 #define  VOLUME_ID_DEFAULT 	"CDROM"
+
 #ifdef __QNX__
 #define  SYSTEM_ID_DEFAULT 	"QNX"
-#else
+#endif
+
+#ifdef __osf__
+#define  SYSTEM_ID_DEFAULT 	"OSF"
+#endif
+
+#ifndef SYSTEM_ID_DEFAULT
 #define  SYSTEM_ID_DEFAULT 	"LINUX"
 #endif
